% CheckNeutral: this function ensures that, if the total charge on our
%               system is near (less than 0.1e) from an integer constant,
%               the total system charge will be neutralized by spreading a
%               neutralizing charge over all atoms in the system.
%               Coordinate information will be left unchanged.
%
%   Arguments:
%   crdq:  an N x 4 matrix containing the XYZ coordinates and charges of
%          each of N atoms (the number of atoms is automatically detected
%          in each of the various sub-procedures)
%
%   Usage:
%   [crdq] = CheckNeutral(crdq);
function crdq = CheckNeutral(crdq)

  % Recall the number of atoms
  natom = size(crdq);
  natom = natom(1,1);
  tq = sum(crdq(:,4));
  if (abs(round(tq) - tq) < 0.1),
    dq = (round(tq) - tq)/natom;
    crdq(:,4) = crdq(:,4) + dq;
  end
end
