% CompXfrm: compute transformation matrices for taking coordinates into
%           and out of box space for a unit cell of dimensions gdim.  Note
%           that gdim is assumed to be a 1 x 6 vector; no checking for its
%           size is done here.
%
%   Arguments:
%   gdim: a 1 x 6 array, the lengths of the lattice vectors in Angstroms
%         followed by the box Alpha, Beta, and Gamma angles in radians
%         (if these angles are not supplied, they will be assumed to be
%         pi/2)
%
%   Usage:
%   [U] = CompXfrm(gdim) returns the transformation matrix for taking
%     coordinates or displacement vectors into the box space
%   [U,invU] = CompXfrm(...) returns the transformation matrix as well as
%     its inverse, so that coordinates and displacements can be taken into
%     the box space and returned to real space
function [U,invU] = CompXfrm(gdim)

  szg = size(gdim);
  szg = szg(2);
  if (szg == 3),
    gdim(4:6) = 0.5*pi;
  end

  dx = cos(gdim(5))*cos(gdim(6)) - cos(gdim(4));
  dx = dx / (sin(gdim(5)) * sin (gdim(6)));
  dy = sqrt(1.0 - dx*dx);
  invU = zeros(3,3);
  invU(1,1) = gdim(1);
  invU(1,2) = gdim(2)*cos(gdim(6));
  invU(1,3) = gdim(3)*cos(gdim(5));
  invU(2,2) = gdim(2)*sin(gdim(6));
  invU(2,3) = -gdim(3)*sin(gdim(5))*dx;
  invU(3,3) = gdim(3)*sin(gdim(5))*dy;
  U = inv(invU);
end
