% Crd2BoxSpace: this function coverts a set of coordinates into box space
%               and keeps them together with their associated charges.
%
%   Arguments:
%   crdq:  an N x 4 matrix containing the XYZ coordinates and charges of
%          each of N atoms (the number of atoms is automatically detected
%          in each of the various sub-procedures)
%   gdim:  a 1 x 6 real array, giving the unit cell lengths in A followed
%          by the unit cell angles in radians
%
%   Usage:
%   [bxcrdq] = Crd2BoxSpace(crdq, gdim) returns an N x 4 array with the
%     coordinates in box space
function bxcrdq = Crd2BoxSpace(crdq, gdim)

  % First, compute the transformation matrices
  [U,invU] = CompXfrm(gdim);

  % Now, transform all coordinates into box space
  natom = size(crdq);
  natom = natom(1,1);
  bxcrdq = crdq';
  bxcrdq(1:3,:) = U*bxcrdq(1:3,:);
  bxcrdq = bxcrdq';

end
