% GammaSum: computes a quantity needed for optimized B grid prefactors.
%
%   Arguments:
%   m:     integer, the distance from 0 assuming that the box wraps around
%          (so, m ranges from -32 to 31 on a grid of 64 points)
%   ng:    scalar integer, the size of the grid (in other functions, ng is
%          a 1 x 3 integer array, but here it is only a scalar)
%   ordr:  the interpolation order
%
%   The value of 50 is hard-coded into this routine, although formally the
%   computation of the Gamma sum is supposed to extend over all integer
%   values of k, from 0 to infinity.
%
%   Usage:
%   [gsum] = GammaSum(m, ng, ordr) returns the Gamma sum value
function gsum = GammaSum(m, ng, ordr)

  gsum = 1.0;

  if (m ~= 0),

    % Double-precision on this, not integer!
    x = pi*m/ng;
    gsum = 1.0;
    for k = 1:1:50,
      gsum = gsum + (x/(x + pi*k))^ordr;
    end
    for k = 1:1:50,
      gsum = gsum + (x/(x - pi*k))^ordr;
    end
  end

end
