% Load data for the ion gas test
load Tests/cubeions.mat

% The AMBER results are based on a slightly wrong value of Coulomb's
% constant: 332.0522 instead of 332.0636.  To make the comparison as good
% as possible, I have to adjust my results by that factor.
ambfac = 332.0522/332.0636;

% Test the PME functions
[frc,fdir,frec] = pmeMain(crdq, [96 96 96], gdim, 4, 1.0e-6, 9.0);
dfdir = sqrt(sum(mean((fdir*ambfac - fdirAMB).^2)));
dfrec = sqrt(sum(mean((frec*ambfac - frecAMB).^2)));
dftot = sqrt(sum(mean(((fdir+frec)*ambfac - (fdirAMB+frecAMB)).^2)));

fprintf('\nThis test concerns a diffuse system of ions in a cubic box.\n\n'); 
fprintf('Error in PME direct space calculation: %9.6f kcal/mol-A\n', dfdir);
fprintf('Error in PME recip. space calculation: %9.6f kcal/mol-A\n', dfrec);
fprintf('Error in PME complete calculation:     %9.6f kcal/mol-A\n\n', dftot);
fprintf('All errors should be less than 0.001 kcal/mol-A in this example.\n');
fprintf('For condensed-phase systems, errors of up to 0.01 kcal/mol-A are ');
fprintf('acceptable.\n');

load Tests/octions.mat

% Test the PME functions
[frc,fdir,frec] = pmeMain(crdq, [128 128 128], gdim, 4, 1.0e-6, 9.0);
dfdir = sqrt(sum(mean((fdir*ambfac - fdirAMB).^2)));
dfrec = sqrt(sum(mean((frec*ambfac - frecAMB).^2)));
dftot = sqrt(sum(mean(((fdir+frec)*ambfac - (fdirAMB+frecAMB)).^2)));

fprintf('\nThis test concerns a diffuse system of ions in a truncated octahedron.\n\n');
fprintf('Error in PME direct space calculation: %9.6f kcal/mol-A\n', dfdir);
fprintf('Error in PME recip. space calculation: %9.6f kcal/mol-A\n', dfrec);
fprintf('Error in PME complete calculation:     %9.6f kcal/mol-A\n\n', dftot);
fprintf('All errors should be less than 0.005 kcal/mol-A in this example.\n');
fprintf('For condensed-phase systems, errors of up to 0.01 kcal/mol-A are ');
fprintf('acceptable.\n');
