% bspln: Function for B-spline computation
%
%    Arguments:
%    x:     the location of the knot
%    ord:   the order of the spline (minimum 2)
%
%    This function is present to emphasize the recursive definition of
%    B-splines.  Much faster implementations (essentially, the piecewise
%    polynomials are pre-evaluated for different orders and hard-coded) are
%    used in MD packages.  See splcof.m for an extremely fast
%    implementation of 4th-order B-splines.
%
%    Usage:
%    [y] = bspln(x,ord) returns the value of the B-spline at x
function y = bspln(x,ord)
  if (ord > 2),
    y = (x/(ord-1))*bspln(x,ord-1) + ((ord-x)/(ord-1))*bspln(x-1.0,ord-1);
  elseif (ord == 2),
    if (x >= 0.0 && x <= 2.0),
      y = 1.0 - abs(x-1.0);
    else
      y = 0.0;
    end
  else
    fprintf('bspln error!  Order = %d\n', ord);
    exit;
  end
end
