% bsplnV: Function for B-spline computation
%
%    Arguments:
%    x:     vector containing the locations of knots
%    ord:   the order of the spline (minimum 2)
%
%    This function is present to emphasize the recursive definition of
%    B-splines.  Much faster implementations (essentially, the piecewise
%    polynomials are pre-evaluated for different orders and hard-coded) are
%    used in MD packages.  See splcof.m for an extremely fast
%    implementation of 4th-order B-splines.
%
%    This function is meant to operate on COLUMN VECTORS, greatly reducing
%    the number of function calls needed.
%
%    Usage:
%    [y] = bsplnV(x,ord) returns the value of the B-spline at x
function y = bsplnV(x,ord)
  if (ord > 2),
    ivo = 1.0/(ord-1);
    y = (x*ivo).*bsplnV(x,ord-1) + ((ord-x)*ivo).*bsplnV(x-1.0,ord-1);
  elseif (ord == 2),
    y = 1.0 - abs(x-1.0);
    y = max(y,0.0);
  else
    fprintf('bsplnV error!  Order = %d\n', ord);
    exit;
  end
end
