% dbspln: Function for B-spline derivative computation
%
%    Arguments:
%    x:     the location of the knot
%    ord:   the order of the spline (minimum 2)
%
%    This function is present to emphasize the definition of B-spline
%    derivatives in terms of lower-order B-splines.  Much faster
%    implementations (essentially, the piecewise polynomials are
%    pre-eavluated for different orders and hard-coded) are used in MD
%    packages.  See splcof.m for an extremely fast implementation of
%    4th-order B-splines.
%
%    Usage:
%    [y] = dbspln(x,ord) returns the derivative of the B-spline at x
function y = dbspln(x,ord)
  if (ord > 2),
    y = bspln(x, ord-1) - bspln(x-1.0, ord-1);
  else
    fprintf('dbspln error!  Order = %d\n', ord);
    exit;
  end
end
