% dbsplnV: Function for B-spline derivative computation
%
%    Arguments:
%    x:     vector containing the locations of knots
%    ord:   the order of the spline (minimum 2)
%
%    This function is present to emphasize the definition of B-spline
%    derivatives in terms of lower-order B-splines.  Much faster
%    implementations (essentially, the piecewise polynomials are
%    pre-eavluated for different orders and hard-coded) are used in MD
%    packages.  See splcof.m for an extremely fast implementation of
%    4th-order B-splines.
%
%    This function is meant to operate on COLUMN VECTORS, greatly reducing
%    the number of function calls needed.  However, it incorporates its own
%    loop, so for computing B-splines on scalar values of x use the
%    original bspln.m function.
%
%    Usage:
%    [y] = dbsplnV(x,ord) returns the derivative of the B-spline at x
function y = dbsplnV(x,ord)
  if (ord > 2),
    y = bsplnV(x, ord-1) - bsplnV(x-1.0, ord-1);
  else
    fprintf('dbsplnV error!  Order = %d\n', ord);
    exit;
  end
end
