% getalpha: this computes the Ewald coefficient.  The method is extremely
%           crude, but it gets the job done and it only has to happen once.
%
%   Arguments:
%   Lcut:   the direct space interaction cutoff
%   Dtol:   the direct sum tolerance
%
%   Essentially, the Ewald coefficient is mathematical shorthand for 1/2s,
%   where s is the width of the Gaussian used to smooth out charges on the
%   grid.  That width is chosen such that, at the direct space interaction
%   cutoff, the interaction of two Gaussian-smoothed charges and the
%   interaction of two poitn charges are identical to a precision of Dtol.
%
%   Note that Dtol determines the accuracy of the direct sum; lower values
%   of Dtol imply a more accurate direct sum, but they also imply a
%   narrower Gaussian which will reduce the accuracy of the reciprocal
%   space sum unless a shorter grid spacing is used.
%
%   For values of Dtol used in typical Ewald simulations, 1.0e-5 and lower,
%   there is a nearly linear relationship between the Gaussian width and
%   the direct space interaction cutoff.
%
%   Usage:
%   [calpha] = getalpha(Lcut, Dtol) returns the Ewald coefficient
function calpha = getalpha(Lcut, Dtol)
  calpha = 1.0;
  maxerr = abs(erfc(calpha*Lcut)/Lcut - Dtol);
  amin = 0.0;
  amax = 10.0;
  for h = 1:1:12,
    dela = 0.005*(amax-amin);
    for i = 0:1:200,
      da = amin + dela*i;
      testa = abs(erfc(da*Lcut)/Lcut - Dtol);
      if (testa < maxerr),
        maxerr = testa;
        calpha = da;
      end
    end
    amin = calpha+5.0*dela;
    amax = calpha-5.0*dela;
  end
end
