% pmeNonOrthoTabBC: even if we are working in an non-orthorhombic unit
%                   cell, prefactors for the grid B can still be computed
%                   (the grid B depends only on the grid dimensions and the
%                   order of interpolation).  The pmeOrthoTabBC.m function
%                   also pre-tabulates prefactors for the Gaussian
%                   convolution grid C, but we can't do that if we don't
%                   know the unit cell is orthorhombic.
%
%   Arguments:
%   ng:    1 x 3 integer array, the dimensions of the grid
%   xyz:   scalar integer, values 1, 2, or 3 acceptable--the dimension for
%          pre-tabulation
%   ordr:  the order of interpolation
%
%   Usage:
%   [bv,mv,ev] = pmeNonOrthoTabBC(ng, xyz, ordr) returns the
%     optimized prefactors for the B grid as bv and components of the
%     frequency vector as mv
function [bv,mv] = pmeNonOrthoTabBC(ng, xyz, ordr)

  % Check input
  if (xyz ~= 1 && xyz ~= 2 && xyz ~= 3),
    fprintf('pmeNonOrthoTabBC: Error.  xyz dimension invalid.\n');
    return
  end

  bv = LoadPrefac(ordr, ng(xyz));
  mv = zeros(ng(xyz),1);

  for i = 1:1:ng(xyz),
    if (i-1 <= ng(xyz)/2),
      mv(i,1) = (i-1);
    else
      mv(i,1) = (i-1-ng(xyz));
    end
  end
  
return
